==> xmonad-dbus-0.1.0.2-228-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-4yDTtUKkynIAnusyur30Mo
key:                  xmonad-dbus-0.1.0.2-4yDTtUKkynIAnusyur30Mo
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  955d23af430710ccc1d3659b496c9837
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-4yDTtUKkynIAnusyur30Mo
depends:              base-4.18.2.1 dbus-1.3.3-JLKUYBHxEnsDh7MSRdPzJN
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-dbus-0.1.0.2-229-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-A2tT4cdXKPc3vJ1VQPC1RG
key:                  xmonad-dbus-0.1.0.2-A2tT4cdXKPc3vJ1VQPC1RG
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  3b4d15530c72f25b280e3b5014dce504
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-A2tT4cdXKPc3vJ1VQPC1RG
depends:              base-4.18.2.1 dbus-1.3.3-KpJgqfUBOE468nxj76vs85
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
